@@ -95,7 +95,8 @@ class FilesystemObjectTests(unittest.TestCase):
                                             sha512=FakeChecksummer(),
                                             md5=FakeChecksummer(),
                                             open_file=FakeOpenFile(),
-                                            readlink=FakeReadlink(self))
+                                            readlink=FakeReadlink(self),
+                                            xattrs={})
 
     def test_raises_keyerror_for_unknown_field(self):
         self.assertRaises(KeyError, self.new('foo').__getitem__,
@@ -207,7 +208,8 @@ class FilesystemObjectNormalizedNumbersTests(unittest.TestCase):
                                             sha512=FakeChecksummer(),
                                             md5=FakeChecksummer(),
                                             open_file=FakeOpenFile(),
-                                            readlink=FakeReadlink(self))
+                                            readlink=FakeReadlink(self),
+                                            xattrs={})
 
     def test_inode_numbers_are_repeatable(self):
         a1 = self.new('foo')
